## ExtremeDT dictionary of parameters

extremeDT_params = [    
{'param': '31',
  'paramName': 'Sea ice area fraction',
  'shortName': 'ci',
  'unit': '(0 - 1)',
  'encoding': 'instantaneous',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'sfc',
  'step': '0/1/to/96',
  'levelist': ''},
 {'param': '34',
  'paramName': 'Sea surface temperature',
  'shortName': 'sst',
  'unit': 'K',
  'encoding': 'instantaneous',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'sfc',
  'step': '0/1/to/96',
  'levelist': ''},
 {'param': '78',
  'paramName': 'Total column cloud liquid water',
  'shortName': 'tclw',
  'unit': 'kg m**-2',
  'encoding': 'instantaneous',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'sfc',
  'step': '0/1/to/96',
  'levelist': ''},
 {'param': '134',
  'paramName': 'Surface pressure',
  'shortName': 'sp',
  'unit': 'Pa',
  'encoding': 'instantaneous',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'sfc',
  'step': '0/1/to/96',
  'levelist': ''},
 {'param': '136',
  'paramName': 'Total column water',
  'shortName': 'tcw',
  'unit': 'kg m**-2',
  'encoding': 'instantaneous',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'sfc',
  'step': '0/1/to/96',
  'levelist': ''},
 {'param': '137',
  'paramName': 'Total column vertically-integrated water vapour',
  'shortName': 'tcwv',
  'unit': 'kg m**-2',
  'encoding': 'instantaneous',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'sfc',
  'step': '0/1/to/96',
  'levelist': ''},
 {'param': '151',
  'paramName': 'Mean sea level pressure',
  'shortName': 'msl',
  'unit': 'Pa',
  'encoding': 'instantaneous',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'sfc',
  'step': '0/1/to/96',
  'levelist': ''},
 {'param': '165',
  'paramName': '10 metre U wind component',
  'shortName': '10u',
  'unit': 'm s**-1',
  'encoding': 'instantaneous',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'sfc',
  'step': '0/1/to/96',
  'levelist': ''},
 {'param': '166',
  'paramName': '10 metre V wind component',
  'shortName': '10v',
  'unit': 'm s**-1',
  'encoding': 'instantaneous',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'sfc',
  'step': '0/1/to/96',
  'levelist': ''},
 {'param': '167',
  'paramName': '2 metre temperature',
  'shortName': '2t',
  'unit': 'K',
  'encoding': 'instantaneous',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'sfc',
  'step': '0/1/to/96',
  'levelist': ''},
 {'param': '168',
  'paramName': '2 metre dewpoint temperature',
  'shortName': '2d',
  'unit': 'K',
  'encoding': 'instantaneous',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'sfc',
  'step': '0/1/to/96',
  'levelist': ''},
 {'param': '3020',
  'paramName': 'Visibility',
  'shortName': 'vis',
  'unit': 'm',
  'encoding': 'instantaneous',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'sfc',
  'step': '0/1/to/96',
  'levelist': ''},
 {'param': '228029',
  'paramName': 'Instantaneous 10 metre wind gust',
  'shortName': 'i10fg',
  'unit': 'm s**-1',
  'encoding': 'instantaneous',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'sfc',
  'step': '0/1/to/96',
  'levelist': ''},
 {'param': '228050',
  'paramName': 'Instantaneous total lightning flash density',
  'shortName': 'litoti',
  'unit': 'km**-2 day**-1',
  'encoding': 'instantaneous',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'sfc',
  'step': '0/1/to/96',
  'levelist': ''},
 {'param': '228218',
  'paramName': 'Convective rain rate',
  'shortName': 'crr',
  'unit': 'kg m**-2 s**-1',
  'encoding': 'instantaneous',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'sfc',
  'step': '0/1/to/96',
  'levelist': ''},
 {'param': '228219',
  'paramName': 'Large scale rain rate',
  'shortName': 'lsrr',
  'unit': 'kg m**-2 s**-1',
  'encoding': 'instantaneous',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'sfc',
  'step': '0/1/to/96',
  'levelist': ''},
 {'param': '228221',
  'paramName': 'Large scale snowfall rate water equivalent',
  'shortName': 'lssfr',
  'unit': 'kg m**-2 s**-1',
  'encoding': 'instantaneous',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'sfc',
  'step': '0/1/to/96',
  'levelist': ''},
 {'param': '228235',
  'paramName': 'Most-unstable CAPE',
  'shortName': 'mucape',
  'unit': 'J kg**-1',
  'encoding': 'instantaneous',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'sfc',
  'step': '0/1/to/96',
  'levelist': ''},
 {'param': '260015',
  'paramName': 'Precipitation type',
  'shortName': 'ptype',
  'unit': 'code table (4.201)',
  'encoding': 'instantaneous',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'sfc',
  'step': '0/1/to/96',
  'levelist': ''},
 {'param': '140221',
  'paramName': 'Mean zero-crossing wave period',
  'shortName': 'mp2',
  'unit': 's',
  'encoding': 'instantaneous',
  'stream': 'wave',
  'type': 'fc',
  'levtype': 'sfc',
  'step': '0/1/to/96',
  'levelist': ''},
 {'param': '140229',
  'paramName': 'Significant height of combined wind waves and swell',
  'shortName': 'swh',
  'unit': 'm',
  'encoding': 'instantaneous',
  'stream': 'wave',
  'type': 'fc',
  'levtype': 'sfc',
  'step': '0/1/to/96',
  'levelist': ''},
 {'param': '140230',
  'paramName': 'Mean wave direction',
  'shortName': 'mwd',
  'unit': 'degrees',
  'encoding': 'instantaneous',
  'stream': 'wave',
  'type': 'fc',
  'levtype': 'sfc',
  'step': '0/1/to/96',
  'levelist': ''},
 {'param': '140231',
  'paramName': 'Peak wave period',
  'shortName': 'pp1d',
  'unit': 's',
  'encoding': 'instantaneous',
  'stream': 'wave',
  'type': 'fc',
  'levtype': 'sfc',
  'step': '0/1/to/96',
  'levelist': ''},
 {'param': '140232',
  'paramName': 'Mean wave period',
  'shortName': 'mwp',
  'unit': 's',
  'encoding': 'instantaneous',
  'stream': 'wave',
  'type': 'fc',
  'levtype': 'sfc',
  'step': '0/1/to/96',
  'levelist': ''},
 {'param': '129',
  'paramName': 'Geopotential',
  'shortName': 'z',
  'unit': 'm**2 s**-2',
  'encoding': 'instantaneous',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'pl',
  'step': '0/1/to/96',
  'levelist': '1/2/3/5/7/10/20/30/50/70/100/150/200/250/300/400/500/700/850/925/1000'},
 {'param': '130',
  'paramName': 'Temperature',
  'shortName': 't',
  'unit': 'K',
  'encoding': 'instantaneous',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'pl',
  'step': '0/1/to/96',
  'levelist': '1/2/3/5/7/10/20/30/50/70/100/150/200/250/300/400/500/700/850/925/1000'},
 {'param': '131',
  'paramName': 'U component of wind',
  'shortName': 'u',
  'unit': 'm s**-1',
  'encoding': 'instantaneous',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'pl',
  'step': '0/1/to/96',
  'levelist': '1/2/3/5/7/10/20/30/50/70/100/150/200/250/300/400/500/700/850/925/1000'},
 {'param': '132',
  'paramName': 'V component of wind',
  'shortName': 'v',
  'unit': 'm s**-1',
  'encoding': 'instantaneous',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'pl',
  'step': '0/1/to/96',
  'levelist': '1/2/3/5/7/10/20/30/50/70/100/150/200/250/300/400/500/700/850/925/1000'},
 {'param': '133',
  'paramName': 'Specific humidity',
  'shortName': 'q',
  'unit': 'kg kg**-1',
  'encoding': 'instantaneous',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'pl',
  'step': '0/1/to/96',
  'levelist': '1/2/3/5/7/10/20/30/50/70/100/150/200/250/300/400/500/700/850/925/1000'},
 {'param': '157',
  'paramName': 'Relative humidity',
  'shortName': 'r',
  'unit': '%',
  'encoding': 'instantaneous',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'pl',
  'step': '0/1/to/96',
  'levelist': '1/2/3/5/7/10/20/30/50/70/100/150/200/250/300/400/500/700/850/925/1000'},
 {'param': '228246',
  'paramName': '100 metre U wind component',
  'shortName': '100u',
  'unit': 'm s**-1',
  'encoding': 'instantaneous',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'hl',
  'step': '0/1/to/96',
  'levelist': '100'},
 {'param': '228247',
  'paramName': '100 metre V wind component',
  'shortName': '100v',
  'unit': 'm s**-1',
  'encoding': 'instantaneous',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'hl',
  'step': '0/1/to/96',
  'levelist': '100'},
 {'param': '228058',
  'paramName': 'Averaged total lightning flash density in the last 6 hours',
  'shortName': 'litota6',
  'unit': 'km**-2 day**-1',
  'encoding': 'mean',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'sfc',
  'step': '0-6/6-12/to/90-96',
  'levelist': ''},
 {'param': '142',
  'paramName': 'Large-scale precipitation',
  'shortName': 'lsp',
  'unit': 'm',
  'encoding': 'accumulated',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'sfc',
  'step': '0-1/1-2/to/95-96',
  'levelist': ''},
 {'param': '144',
  'paramName': 'Snowfall',
  'shortName': 'sf',
  'unit': 'm of water equivalent',
  'encoding': 'accumulated',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'sfc',
  'step': '0-1/1-2/to/95-96',
  'levelist': ''},
 {'param': '169',
  'paramName': 'Surface short-wave (solar) radiation downwards',
  'shortName': 'ssrd',
  'unit': 'J m**-2',
  'encoding': 'accumulated',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'sfc',
  'step': '0-1/1-2/to/95-96',
  'levelist': ''},
 {'param': '175',
  'paramName': 'Surface long-wave (thermal) radiation downwards',
  'shortName': 'strd',
  'unit': 'J m**-2',
  'encoding': 'accumulated',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'sfc',
  'step': '0-1/1-2/to/95-96',
  'levelist': ''},
 {'param': '176',
  'paramName': 'Surface net short-wave (solar) radiation',
  'shortName': 'ssr',
  'unit': 'J m**-2',
  'encoding': 'accumulated',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'sfc',
  'step': '0-1/1-2/to/95-96',
  'levelist': ''},
 {'param': '177',
  'paramName': 'Surface net long-wave (thermal) radiation',
  'shortName': 'str',
  'unit': 'J m**-2',
  'encoding': 'accumulated',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'sfc',
  'step': '0-1/1-2/to/95-96',
  'levelist': ''},
 {'param': '178',
  'paramName': 'Top net short-wave (solar) radiation',
  'shortName': 'tsr',
  'unit': 'J m**-2',
  'encoding': 'accumulated',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'sfc',
  'step': '0-1/1-2/to/95-96',
  'levelist': ''},
 {'param': '179',
  'paramName': 'Top net long-wave (thermal) radiation',
  'shortName': 'ttr',
  'unit': 'J m**-2',
  'encoding': 'accumulated',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'sfc',
  'step': '0-1/1-2/to/95-96',
  'levelist': ''},
 {'param': '180',
  'paramName': 'Time-integrated eastward turbulent surface stress',
  'shortName': 'ewss',
  'unit': 'N m**-2 s',
  'encoding': 'accumulated',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'sfc',
  'step': '0-1/1-2/to/95-96',
  'levelist': ''},
 {'param': '181',
  'paramName': 'Time-integrated northward turbulent surface stress',
  'shortName': 'nsss',
  'unit': 'N m**-2 s',
  'encoding': 'accumulated',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'sfc',
  'step': '0-1/1-2/to/95-96',
  'levelist': ''},
 {'param': '205',
  'paramName': 'Runoff',
  'shortName': 'ro',
  'unit': 'm',
  'encoding': 'accumulated',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'sfc',
  'step': '0-1/1-2/to/95-96',
  'levelist': ''},
 {'param': '228',
  'paramName': 'Total precipitation',
  'shortName': 'tp',
  'unit': 'm',
  'encoding': 'accumulated',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'sfc',
  'step': '0-1/1-2/to/95-96',
  'levelist': ''},
 {'param': '228216',
  'paramName': 'Accumulated freezing rain',
  'shortName': 'fzra',
  'unit': 'm',
  'encoding': 'accumulated',
  'stream': 'oper',
  'type': 'fc',
  'levtype': 'sfc',
  'step': '0-1/1-2/to/95-96',
  'levelist': ''}
]

## Extreme DT scenarios to choose from
extremeDT_scenario = [
{
  'model': 'IFS-NEMO',
  'dateFrom': '04/04/2024',
  'dateTo': '04/12/2024'
}
]